@@ -355,16 +355,6 @@ macro_rules! if_futures {
     }
 }
 
-#[doc(hidden)]
-#[macro_export]
-macro_rules! debug {
-    ($($t:tt)*) => {
-        if $crate::__debug_enabled() {
-            println!($($t)*);
-        }
-    };
-}
-
 macro_rules! dbg {
     ($($t:tt)*) => {
         $($t)*
@@ -392,11 +382,6 @@ if_futures! {
     pub mod future;
 }
 
-#[doc(hidden)]
-pub fn __debug_enabled() -> bool {
-    rt::execution(|e| e.log)
-}
-
 /// Mock version of `std::thread_local!`.
 // This is defined *after* all other code in `loom`, since we use
 // `scoped_thread_local!` internally, which uses the `std::thread_local!` macro
