@@ -34,7 +34,20 @@ impl Thread {
 
     /// Returns the (optional) name of this thread
     pub fn name(&self) -> Option<&str> {
-        self.name.as_ref().map(|s| s.as_str())
+        self.name.as_deref()
+    }
+
+    /// Mock implementation of [`std::thread::unpark`].
+    ///
+    /// Atomically makes the handle's token available if it is not already.
+    ///
+    /// Every thread is equipped with some basic low-level blocking support, via
+    /// the [`park`][park] function and the `unpark()` method. These can be
+    /// used as a more CPU-efficient implementation of a spinlock.
+    ///
+    /// See the [park documentation][park] for more details.
+    pub fn unpark(&self) {
+        rt::execution(|execution| execution.threads.unpark(self.id.id));
     }
 }
 
@@ -116,6 +129,16 @@ where
     spawn_internal(f, None)
 }
 
+/// Mock implementation of `std::thread::park`.
+///
+///  Blocks unless or until the current thread's token is made available.
+///
+/// A call to `park` does not guarantee that the thread will remain parked
+/// forever, and callers should be prepared for this possibility.
+pub fn park() {
+    rt::park();
+}
+
 fn spawn_internal<F, T>(f: F, name: Option<String>) -> JoinHandle<T>
 where
     F: FnOnce() -> T,
@@ -151,6 +174,9 @@ where
 impl Builder {
     /// Generates the base configuration for spawning a thread, from which
     /// configuration methods can be chained.
+    // `std::thread::Builder` does not implement `Default`, so this type does
+    // not either, as it's a mock version of the `std` type.
+    #[allow(clippy::new_without_default)]
     pub fn new() -> Builder {
         Builder { name: None }
     }
